Introduction
============

This package provides MathJax as browser resources for Plone and registers them
in the Resource Registry.

https://github.com/mathjax/MathJax

http://www.mathjax.org/demos/tex-samples/

http://en.wikipedia.org/wiki/MathJax


Author
======

Johannes Raggam, BlueDynamics Alliance <raggam-nl [at] adm [dot] at>
